@@ -10,13 +10,13 @@ my $email = '';
 my $password = '';
 
 # your developer token
-my $dev_token = '';
+my $dev_token = $email . '++INR';
 
 # your application token
 my $app_token = '';
 
 # your client email if you use a MCC
-my $client_email = '';
+my $client_email = 'client_2+' . $email;
 
 
 my $service = Google::Adwords::InfoService->new();
@@ -28,7 +28,7 @@ $service->email($email)
 ;
 
 # debug
-$service->debug(1);
+#$service->debug(1);
 
 # client email
 if ((defined $client_email) && ($client_email ne '')) {
